# -*- coding:UTF-8 -*-
from pyuts.py_crawl.scrapyCommandU import ScrapyCommandU


class Scrapycommandname(ScrapyCommandU):
    
    def run(self, args, opts):
        print(args)
        # self.runSpider("Test")
        # self.start_crawl()